@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.1104';
+our $VERSION = '0.1105';
 
 use Moo;
 use strictures 2;
@@ -417,7 +417,7 @@ sub _is_list {
 
 sub _is_boolean {
     croak 'Invalid Boolean'
-        unless defined $_[0] && ( $_[0] == 1 || $_[0] == 0 );
+        unless defined $_[0] && $_[0] =~ /^\d$/ && ( $_[0] == 1 || $_[0] == 0 );
 }
 
 1;
@@ -434,7 +434,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.1104
+version 0.1105
 
 =head1 SYNOPSIS
 
@@ -499,6 +499,8 @@ The maximum number of phrases to analyze/play.
 
 Default: C<10>
 
+Setting this to a value of C<0> analyzes all phrases.
+
 =head2 bpm
 
 Beats per minute.
@@ -582,8 +584,8 @@ Default: C<0>
 
 =head2 score
 
-The score object in L<MIDI::Simple/"MAIN-ROUTINES">.  Constructed at
-runtime.
+The score object in L<MIDI::Simple/"MAIN-ROUTINES">.  Constructed by
+the B<populate> method.
 
 =head2 notes
 
